Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1114)

Unified Diff: runtime/vm/bootstrap.h

Issue 2525623002: VM: [Kernel] Split kernel API into 3 steps: ([read binary], parse-binary, bootstrap, load program) (Closed)
Patch Set: addressed comments Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/include/dart_api.h ('k') | runtime/vm/bootstrap.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/bootstrap.h
diff --git a/runtime/vm/bootstrap.h b/runtime/vm/bootstrap.h
index 77fb556f450fb264c6b8a7b0c01a8abc31e123f1..15f454b2ea131e33901196402272bcd147970c81 100644
--- a/runtime/vm/bootstrap.h
+++ b/runtime/vm/bootstrap.h
@@ -12,17 +12,19 @@ namespace dart {
// Forward declarations.
class RawError;
+namespace kernel {
+class Program;
+}
class Bootstrap : public AllStatic {
public:
// Compile the bootstrap libraries, either from sources or a Kernel binary.
// If kernel_buffer is NULL, compile from sources or source paths linked into
// the VM. If it is non-NULL it represents a buffer holding a Kernel binary.
// The caller of this function is responsible for managing the kernel
- // buffer's memory, and is welcome to deallocate it after this function
- // returns.
- static RawError* DoBootstrapping(const uint8_t* kernel_buffer,
- intptr_t kernel_buffer_length);
+ // program's memory.
+ static RawError* DoBootstrapping(kernel::Program* program);
static void SetupNativeResolver();
static bool IsBootstapResolver(Dart_NativeEntryResolver resolver);
« no previous file with comments | « runtime/include/dart_api.h ('k') | runtime/vm/bootstrap.cc » ('j') | no next file with comments »
@@ -12,17 +12,19 @@ namespace dart {
class Bootstrap : public AllStatic {
public:
- // Compile the bootstrap libraries, either from sources or a Kernel binary.
- // If kernel_buffer is NULL, compile from sources or source paths linked into
- // the VM. If it is non-NULL it represents a buffer holding a Kernel binary.
+ // Compile the bootstrap libraries, either from sources or a Kernel program.
+ // If program is NULL, compile from sources or source paths linked into
+ // the VM. If it is non-NULL it represents the Kernel program to use for
+ // bootstrapping.
// The caller of this function is responsible for managing the kernel

Powered by Google App Engine
This is Rietveld 408576698